Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorYue Ma2014-05-07 12:54:17 +0000
committerYue Ma2014-05-07 12:54:17 +0000
commit763b128d3fec6ed7ca73086f603b8e401789ee6e (patch)
tree3d3e04968c40f869815fd589512fbb4dbb00860c
parentcfa26b1f8fd17554e3ae2b69ad57eda294935446 (diff)
downloadorg.eclipse.sphinx-763b128d3fec6ed7ca73086f603b8e401789ee6e.tar.gz
org.eclipse.sphinx-763b128d3fec6ed7ca73086f603b8e401789ee6e.tar.xz
org.eclipse.sphinx-763b128d3fec6ed7ca73086f603b8e401789ee6e.zip
Restored wget-based artifacts download
-rw-r--r--releng/org.eclipse.sphinx.releng.builds/publish.sh17
1 files changed, 10 insertions, 7 deletions
diff --git a/releng/org.eclipse.sphinx.releng.builds/publish.sh b/releng/org.eclipse.sphinx.releng.builds/publish.sh
index 4dd1f3db..58c04c4e 100644
--- a/releng/org.eclipse.sphinx.releng.builds/publish.sh
+++ b/releng/org.eclipse.sphinx.releng.builds/publish.sh
@@ -14,10 +14,12 @@ eclipsePackageTimestamp=201302041200
eclipsePackagePath=$eclipseDownloadsPath/eclipse/downloads/drops4/R-$eclipsePackageVersion-$eclipsePackageTimestamp
eclipsePackageFileName=eclipse-SDK-$eclipsePackageVersion-linux-gtk-x86_64.tar.gz
-targetBuildRelativePath=$(echo "$TARGET_BUILD_RUN" | grep -o '/[^/]\+/[0-9]\+/$')
+# TODO Find a way to insert missing "builds" path segment in targetBuildRelativePath, e.g., sphinx-0.8-luna/95 => sphinx-0.8-luna/builds/95
+targetBuildRelativePath=$(echo "$TARGET_BUILD_RUN" | grep -o '[^/]\+/[0-9]\+')
relengProjectRelativePath=releng/org.eclipse.sphinx.releng.builds
-originalArtifactsRelativePath=artifact/$relengProjectRelativePath/repository/target/repository/
-originalArtifactsPath=${WORKSPACE}/../../$targetBuildRelativePath/$originalArtifactsRelativePath
+originalArtifactsRelativePath=$relengProjectRelativePath/repository/target/repository
+originalArtifactsPath=${WORKSPACE}/../../$targetBuildRelativePath/archive/$originalArtifactsRelativePath
+originalArtifactsURL=$TARGET_BUILD_RUN/artifact/$originalArtifactsRelativePath
localRelengProjectPath=${WORKSPACE}/$relengProjectRelativePath
localArtifactsDirectoryName=artifacts
localArtifactsPath=$localRelengProjectPath/$localArtifactsDirectoryName
@@ -26,13 +28,14 @@ buildEclipsePath=$localRelengProjectPath/eclipse
releaseStreamPrefix=0.8
updateZipFileNamePrefix=sphinx-Update-$releaseStreamPrefix.0
-echo "Copying $originalArtifactsPath/* to $localArtifactsPath/*"
+echo "Downloading $originalArtifactsURL/* to $localArtifactsPath/*"
rm -rf $localArtifactsPath
-cp -R $originalArtifactsPath/* $localArtifactsPath/
+wget --mirror --execute robots=off --directory-prefix=$localArtifactsPath --no-host-directories --cut-dirs=11 --no-parent --reject="index.html*,*zip*" --timestamping $originalArtifactsURL/
-# Alternative approach: download build artifacts rather than copying them
+# Alternative approach: copy build artifacts rather than downloading them
+# echo "Copying $originalArtifactsPath/* to $localArtifactsPath/*"
# rm -rf $localArtifactsPath
-# wget --mirror --execute robots=off --directory-prefix=$localArtifactsPath --no-host-directories --cut-dirs=11 --no-parent --reject="index.html*,*zip*" --timestamping $TARGET_BUILD_RUN/artifact/releng/org.eclipse.sphinx.releng.builds/repository/target/repository/
+# cp -R $originalArtifactsPath/* $localArtifactsPath/
# Determine remote update site we want to promote to (integration and stable builds are published on interim update site, release builds on applicable release stream update site)
case $TARGET_BUILD_TYPE in

Back to the top